@@ -2,7 +2,7 @@
 
 install_deps() {
   apt-get update
-  apt-get install -y cmake gcc g++ libncurses5-dev libncursesw5-dev libdrm-dev wget file libudev-dev
+  apt-get install -y gcc g++ libncurses5-dev libncursesw5-dev libdrm-dev wget file libudev-dev
 }
 
 configure_nvtop() {
@@ -23,8 +23,15 @@ get_linuxdeploy() {
   ./linuxdeploy-x86_64.AppImage --appimage-extract
 }
 
+get_cmake() {
+  wget -nc https://github.com/Kitware/CMake/releases/download/v3.18.0/cmake-3.18.0.tar.gz
+  tar zxf cmake-3.18.0.tar.gz
+  ./cmake-3.18.0/bootstrap --prefix=/usr && make && make install
+}
+
 create_AppImage() {
   install_deps
+  get_cmake
   mkdir nvtop_build
   cd nvtop_build
   configure_nvtop
