@@ -65,6 +65,9 @@ struct device_window {
   WINDOW *gpu_clock_info;
   WINDOW *mem_clock_info;
   WINDOW *pcie_info;
+  WINDOW *shader_cores;
+  WINDOW *l2_cache_size;
+  WINDOW *exec_engines;
   bool enc_was_visible;
   bool dec_was_visible;
   nvtop_time last_decode_seen;
@@ -140,6 +143,9 @@ enum device_field {
   device_power,
   device_pcie,
   device_clock,
+  device_shadercores,
+  device_l2features,
+  device_execengines,
   device_field_count,
 };
 
