@@ -253,6 +253,17 @@ bool gpuinfo_refresh_processes(struct list_head *devices) {
   return true;
 }
 
+bool gpuinfo_utilisation_rate(struct list_head *devices) {
+  struct gpu_info *device;
+
+  list_for_each_entry(device, devices, list) {
+    if (device->vendor->refresh_utilisation_rate)
+      device->vendor->refresh_utilisation_rate(device);
+  }
+
+  return true;
+}
+
 void gpuinfo_clear_cache(void) {
   if (cached_process_info) {
     struct process_info_cache *pid_cached, *tmp;
@@ -311,3 +322,40 @@ unsigned nvtop_pcie_gen_from_link_speed(unsigned linkSpeed) {
   }
   return pcieGen;
 }
+
+void gpuinfo_refresh_utilisation_rate(struct gpu_info *gpu_info) {
+  /*
+   * kernel Documentation/gpu/drm-usage-stats.rst:
+   *  - drm-maxfreq-<keystr>: <uint> [Hz|MHz|KHz]
+   *  Engine identifier string must be the same as the one specified in the
+   *  drm-engine-<keystr> tag and shall contain the maximum frequency for the given
+   *  engine. Taken together with drm-cycles-<keystr>, this can be used to calculate
+   *  percentage utilization of the engine, whereas drm-engine-<keystr> only reflects
+   *  time active without considering what frequency the engine is operating as a
+   *  percentage of it's maximum frequency.
+   *
+   */
+
+  uint64_t gfx_total_process_cycles = 0;
+  uint64_t total_delta = 0;
+  unsigned int utilisation_rate;
+  uint64_t max_freq_hz;
+  double avg_delta_secs;
+
+  for (unsigned processIdx = 0; processIdx < gpu_info->processes_count; ++processIdx) {
+    struct gpu_process *process_info = &gpu_info->processes[processIdx];
+
+    gfx_total_process_cycles += process_info->gpu_cycles;
+    total_delta += process_info->sample_delta;
+  }
+
+  if (!gfx_total_process_cycles)
+    return;
+
+  avg_delta_secs = ((double)total_delta / gpu_info->processes_count) / 1000000000.0;
+  max_freq_hz = gpu_info->dynamic_info.gpu_clock_speed_max * 1000000;
+  utilisation_rate = (unsigned int)((((double)gfx_total_process_cycles) / (((double)max_freq_hz) * avg_delta_secs * 2)) * 100);
+  utilisation_rate = utilisation_rate > 100 ? 100 : utilisation_rate;
+
+  SET_GPUINFO_DYNAMIC(&gpu_info->dynamic_info, gpu_util_rate, utilisation_rate);
+}
