@@ -21,6 +21,7 @@
 
 #include "nvtop/interface_options.h"
 #include "ini.h"
+#include "nvtop/extract_processinfo_fdinfo.h"
 #include "nvtop/interface_common.h"
 
 #include <assert.h>
@@ -42,6 +43,8 @@ static const char *default_config_path(void) {
   if (!xdg_config_dir) {
     // XDG config dir not set, default to $HOME/.config
     xdg_config_dir = getenv("HOME");
+    if (!xdg_config_dir)
+            return NULL;
     conf_path_length = sizeof(config_conf_path);
   }
   size_t xdg_path_length = strlen(xdg_config_dir);
@@ -98,6 +101,8 @@ unsigned interface_check_and_fix_monitored_gpus(unsigned num_devices, struct lis
     options->gpu_specific_opts[0].doNotMonitor = false;
     numMonitored++;
   }
+  list_for_each_entry(device, monitoredGpu, list) { processinfo_enable_disable_callback_for(device, true); }
+  list_for_each_entry(device, nonMonitoredGpu, list) { processinfo_enable_disable_callback_for(device, false); }
   return numMonitored;
 }
 
@@ -123,6 +128,7 @@ void alloc_interface_options_internals(char *config_location, unsigned num_devic
   options->has_monitored_set_changed = false;
   options->show_startup_messages = true;
   options->filter_nvtop_pid = true;
+  options->has_gpu_info_bar = false;
   if (config_location) {
     options->config_file_location = malloc(strlen(config_location) + 1);
     if (!options->config_file_location) {
@@ -132,12 +138,14 @@ void alloc_interface_options_internals(char *config_location, unsigned num_devic
     strcpy(options->config_file_location, config_location);
   } else {
     const char *default_path = default_config_path();
-    options->config_file_location = malloc(strlen(default_path) + 1);
-    if (!options->config_file_location) {
-      perror("Cannot allocate memory: ");
-      exit(EXIT_FAILURE);
+    if (default_path) {
+      options->config_file_location = malloc(strlen(default_path) + 1);
+      if (!options->config_file_location) {
+	perror("Cannot allocate memory: ");
+	exit(EXIT_FAILURE);
+      }
+      strcpy(options->config_file_location, default_path);
     }
-    strcpy(options->config_file_location, default_path);
   }
 }
 
@@ -162,6 +170,7 @@ static const char general_show_messages[] = "ShowInfoMessages";
 static const char header_section[] = "HeaderOption";
 static const char header_value_use_fahrenheit[] = "UseFahrenheit";
 static const char header_value_encode_decode_timer[] = "EncodeHideTimer";
+static const char header_value_gpu_info_bar[] = "GPUInfoBar";
 
 static const char chart_section[] = "ChartOption";
 static const char chart_value_reverse[] = "ReverseChart";
@@ -225,6 +234,14 @@ static int nvtop_option_ini_handler(void *user, const char *section, const char
       if (sscanf(value, "%le", &value_double) == 1)
         ini_data->options->encode_decode_hiding_timer = value_double;
     }
+    if (strcmp(name, header_value_gpu_info_bar) == 0) {
+      if (strcmp(value, "true") == 0) {
+        ini_data->options->has_gpu_info_bar = true;
+      }
+      if (strcmp(value, "false") == 0) {
+        ini_data->options->has_gpu_info_bar = false;
+      }
+    }
   }
   // Chart Options
   if (strcmp(section, chart_section) == 0) {
@@ -346,6 +363,8 @@ static bool create_config_directory_rec(char *config_directory) {
 static const char *boolean_string(bool value) { return value ? "true" : "false"; }
 
 bool save_interface_options_to_config_file(unsigned total_dev_count, const nvtop_interface_option *options) {
+  if (!options->config_file_location)
+    return false;
 
   char folder_path[PATH_MAX];
   strcpy(folder_path, options->config_file_location);
@@ -371,6 +390,7 @@ bool save_interface_options_to_config_file(unsigned total_dev_count, const nvtop
   fprintf(config_file, "\n[%s]\n", header_section);
   fprintf(config_file, "%s = %s\n", header_value_use_fahrenheit, boolean_string(options->temperature_in_fahrenheit));
   fprintf(config_file, "%s = %e\n", header_value_encode_decode_timer, options->encode_decode_hiding_timer);
+  fprintf(config_file, "%s = %s\n", header_value_gpu_info_bar, boolean_string(options->has_gpu_info_bar));
 
   // Chart Options
   fprintf(config_file, "\n[%s]\n", chart_section);
